@@ -74,15 +74,20 @@ class ItemUploader(object):
         need to be set.
     :param pipeline_workflow_id: Pipeline workflow ID.
     :param non_retry_list: List of status codes for which we don't want a
-        retry/backoff logic.
-        Defaults to [200, 202, 401, 403, 400, 404]
-        200, 202: Successful codes.
-        401, 403: Already have a retry block in the _perform_request method
-                    of Squirro Client.
-        400, 404: Does not make sense to retry for these codes as retrying
-                    won't fix the underlying issue.
+        retry/backoff logic. Defaults to `[200, 202, 401, 403, 400, 404]`.
 
-    Typical usage:
+        200, 202
+            Successful codes.
+
+        401, 403
+            Already have a retry block in the _perform_request method of
+            Squirro Client.
+
+        400, 404
+            Does not make sense to retry for these codes as retrying won't fix
+            the underlying issue.
+
+    Typical usage::
 
         >>> from squirro_client import ItemUploader
         >>> uploader = ItemUploader(project_title='My Project',
@@ -472,8 +477,8 @@ class ItemUploader(object):
     ):
         """Sends ``items`` to Squirro.
 
-        :param items: A list of items. See
-            :ref:`api_reference_sink_data_format` for the item format.
+        :param items: A list of items. See the `Item Format`_ documentation for
+            the keys and values of the individual items.
         :param priority: int, describing the priority of ingestion for the
             dataset to be loaded. Currently only supports a value of `0` or `1`.
             `0` means that the items are loaded in an asynchronous fashion and
