@@ -9,11 +9,6 @@ from .community_subscription import CommunitySubscriptionsMixin
 from .community_types import CommunityTypesMixin
 from .contributingrecords import ContributingRecordsMixin
 from .dashboards import DashboardsMixin
-from .dss_candidate_set import DSSCandidateSet
-from .dss_groundtruth import DSSGroundTruthMixin
-from .dss_model import DSSModels
-from .dss_publish import DSSPublish
-from .dss_template import DSSTemplates
 from .email_templates import EmailTemplatesMixin
 from .enrichments import EnrichmentsMixin
 from .entities import EntitiesMixin
@@ -22,6 +17,13 @@ from .file_upload import FileUploadMixin
 from .globaltemp import GlobalTempMixin
 from .guidefiles import ProjectGuideFilesMixin
 from .machinelearning import MachineLearningMixin
+from .ml_candidate_set import MLCandidateSetMixin
+from .ml_groundtruth import MLGroundTruthMixin
+from .ml_model import MLModelsMixin
+from .ml_publish import MLPublishMixin
+from .ml_sentence_splitter import MLSentenceSplitterMixin
+from .ml_template import MLTemplatesMixin
+from .ml_user_feedback import MLUserFeedbackMixin
 from .objects import ObjectsMixin
 from .pipeline_status import PipelineStatusMixin
 from .pipeline_workflows import PipelineWorkflowMixin
@@ -42,8 +44,7 @@ MAX_UPDATE_SIZE = 80 * 1024 * 1024  # 80 MB (nginx has 96 MB limit)
 
 class TopicApiBaseMixin(object):
     def get_projects(self):
-        """Return all projects.
-        """
+        """Return all projects."""
         # Build URL
         url = "%(ep)s/v0/%(tenant)s/projects" % {
             "ep": self.topic_api_url,
@@ -401,7 +402,7 @@ class TopicApiBaseMixin(object):
 
         :param count: number of return recommendations
         :param explanation_count: number of return explanations for each
-        recommendations, explanations are sorted by score, default is 1
+            recommendations, explanations are sorted by score, default is 1
         :param data: input data, json object containing flowing fields:
 
             - input_features: dictionary of input facets. Each feature is a
@@ -660,7 +661,7 @@ class TopicApiBaseMixin(object):
 
         :param count: number of return recommendations
         :param explanation_count: number of return explanations for each
-        recommendations, explanations are sorted by score, default is 1
+            recommendations, explanations are sorted by score, default is 1
         :param data: input data, json object containing flowing fields:
 
             - input_features: dictionary of input entity properties. Each
@@ -782,9 +783,9 @@ class TopicApiBaseMixin(object):
         :param query: query to match entity. Use item query syntax,
             e.g entity:{type:career}
         :param aggregations: Aggregation of entity fields. For numeric
-            property you need to add prefix numeric_ to field name,
-            e.g. numeric_properties.salary. We support 2 methods of
-            aggregations: "terms" and "stats"(for numeric_properties).
+            property you need to add prefix `numeric_` to field name,
+            e.g. `numeric_properties.salary`. We support 2 methods of
+            aggregations: "terms" and "stats" (for numeric properties).
             Default method is "terms" aggregation.
 
         :return: List of entities and aggregations
@@ -1592,7 +1593,6 @@ class TopicApiMixin(
     FileUploadMixin,
     GlobalTempMixin,
     MachineLearningMixin,
-    DSSGroundTruthMixin,
     ObjectsMixin,
     PipelineStatusMixin,
     PipelineWorkflowMixin,
@@ -1607,9 +1607,12 @@ class TopicApiMixin(
     ThemesMixin,
     TrendDetectionMixin,
     WidgetsAndAssetsMixin,
-    DSSCandidateSet,
-    DSSTemplates,
-    DSSModels,
-    DSSPublish,
+    MLCandidateSetMixin,
+    MLGroundTruthMixin,
+    MLTemplatesMixin,
+    MLModelsMixin,
+    MLPublishMixin,
+    MLUserFeedbackMixin,
+    MLSentenceSplitterMixin,
 ):
     pass
