@@ -18,6 +18,7 @@ class ProjectsMixin(object):
             "theme",
             "integration_dashboards",
             "first_visit",
+            "newsletter_config",
         ]
     )
 
@@ -321,7 +322,6 @@ class ProjectsMixin(object):
                 data[key] = kwargs[key]
 
         headers = {"Content-Type": "application/json"}
-
         res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [201, 204])
 
@@ -519,6 +519,7 @@ class ProjectsMixin(object):
         :param export_items_config: Dict. Containing the query parameters that
             can be used to filter down the exported items. Currently only
             `query` and `count` parameters are supported.
+
         Example::
 
             >>> res = client.export_project(
@@ -623,7 +624,7 @@ class ProjectsMixin(object):
             exported_file = self._get_file_name(res)
             with open(exported_file, "wb") as exported_project:
                 exported_project.write(res.content)
-                print("Exported project to ./{}".format(exported_file))
+                log.info("Exported project to ./%s", exported_file)
             return
 
         return {"data": res.content, "headers": res.headers, "status": "done"}
@@ -686,7 +687,7 @@ class ProjectsMixin(object):
         corresponding keyword argument to `False` or `True` respectively.
 
         This method returns a requests.Response object.
-        See http://docs.python-requests.org/en/master/api/#requests.Response for  # noqa
+        See http://docs.python-requests.org/en/master/api/#requests.Response for
         more details.
 
         :param project_id: Project identifier.
@@ -699,8 +700,8 @@ class ProjectsMixin(object):
             dashboards custom widgets. This only applies if `import_dashboards`
             is set to `True`. Defaults to `True`.
         :param import_dashboard_loaders: Boolean. Whether to include the
-            dashboards loaders and dashboards themes. This only applies if `import_dashboards`
-            is set to `True`. Defaults to `True`.
+            dashboards loaders and dashboards themes. This only applies if
+            `import_dashboards` is set to `True`. Defaults to `True`.
         :param import_email_templates: Boolean. Whether to include the email
             templates. Defaults to `True`.
         :param import_pipeline_workflows: Boolean. Whether to include the
@@ -742,6 +743,7 @@ class ProjectsMixin(object):
             also.
         :param import_guide_file: Boolean. Whether to include the project guide file,
             defaults to `True`.
+
         Example::
 
             >>> res = client.import_project(
