@@ -1,7 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import json
-from builtins import object
 
 
 class SynonymsMixin(object):
